@@ -242,7 +242,7 @@ AgendaHeader::AgendaHeader(bool isSideBySide, QWidget *parent)
     , mIsSideBySide(isSideBySide)
 {
     auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     if (mIsSideBySide) {
         mCalendarNameLabel = new KSqueezedTextLabel(this);
@@ -254,20 +254,20 @@ AgendaHeader::AgendaHeader(bool isSideBySide, QWidget *parent)
     layout->addWidget(daysWidget);
 
     auto daysLayout = new QHBoxLayout(daysWidget);
-    daysLayout->setContentsMargins(0, 0, 0, 0);
+    daysLayout->setContentsMargins({});
     daysLayout->setSpacing(SPACING);
 
     if (!mIsSideBySide) {
         mWeekLabelBox = new QWidget(daysWidget);
         auto weekLabelBoxLayout = new QVBoxLayout(mWeekLabelBox);
-        weekLabelBoxLayout->setContentsMargins(0, 0, 0, 0);
+        weekLabelBoxLayout->setContentsMargins({});
         weekLabelBoxLayout->setSpacing(0);
         daysLayout->addWidget(mWeekLabelBox);
     }
 
     mDayLabels = new QWidget(daysWidget);
     mDayLabelsLayout = new AgendaHeaderLayout(mDayLabels);
-    mDayLabelsLayout->setContentsMargins(0, 0, 0, 0);
+    mDayLabelsLayout->setContentsMargins({});
     daysLayout->addWidget(mDayLabels);
     daysLayout->setStretchFactor(mDayLabels, 1);
 }
@@ -369,7 +369,7 @@ void AgendaHeader::addDay(const DecorationList &decoList, QDate date, bool withD
 {
     auto topDayLabelBox = new QWidget(mDayLabels);
     auto topDayLabelBoxLayout = new QVBoxLayout(topDayLabelBox);
-    topDayLabelBoxLayout->setContentsMargins(0, 0, 0, 0);
+    topDayLabelBoxLayout->setContentsMargins({});
     topDayLabelBoxLayout->setSpacing(0);
 
     mDayLabelsLayout->addWidget(topDayLabelBox);
@@ -416,7 +416,7 @@ void AgendaHeader::placeDecorations(const DecorationList &decoList, QDate date,
             labelBox->layout()->addWidget(decoHBox);
             auto layout = new QHBoxLayout(decoHBox);
             layout->setSpacing(0);
-            layout->setContentsMargins(0, 0, 0, 0);
+            layout->setContentsMargins({});
             decoHBox->setMinimumWidth(1);
 
             for (CalendarDecoration::Element *it : elements) {
@@ -1117,7 +1117,7 @@ void AgendaView::init(QDate start, QDate end)
     d->mSelectedDates = AgendaViewPrivate::generateDateList(start, end);
 
     d->mMainLayout = new QVBoxLayout(this);
-    d->mMainLayout->setContentsMargins(0, 0, 0, 0);
+    d->mMainLayout->setContentsMargins({});
 
     /* Create day name labels for agenda columns */
     d->mTopDayLabelsFrame = new AgendaHeader(d->mIsSideBySide, this);
@@ -1130,7 +1130,7 @@ void AgendaView::init(QDate start, QDate end)
     /* Create all-day agenda widget */
     d->mAllDayFrame = new QWidget(d->mSplitterAgenda);
     auto allDayFrameLayout = new QHBoxLayout(d->mAllDayFrame);
-    allDayFrameLayout->setContentsMargins(0, 0, 0, 0);
+    allDayFrameLayout->setContentsMargins({});
     allDayFrameLayout->setSpacing(SPACING);
 
     // Alignment and description widgets
@@ -1138,7 +1138,7 @@ void AgendaView::init(QDate start, QDate end)
         d->mTimeBarHeaderFrame = new QWidget(d->mAllDayFrame);
         allDayFrameLayout->addWidget(d->mTimeBarHeaderFrame);
         auto timeBarHeaderFrameLayout = new QHBoxLayout(d->mTimeBarHeaderFrame);
-        timeBarHeaderFrameLayout->setContentsMargins(0, 0, 0, 0);
+        timeBarHeaderFrameLayout->setContentsMargins({});
         timeBarHeaderFrameLayout->setSpacing(0);
         d->mDummyAllDayLeft = new QWidget(d->mAllDayFrame);
         allDayFrameLayout->addWidget(d->mDummyAllDayLeft);
@@ -1152,7 +1152,7 @@ void AgendaView::init(QDate start, QDate end)
     /* Create the main agenda widget and the related widgets */
     auto agendaFrame = new QWidget(d->mSplitterAgenda);
     auto agendaLayout = new QHBoxLayout(agendaFrame);
-    agendaLayout->setContentsMargins(0, 0, 0, 0);
+    agendaLayout->setContentsMargins({});
     agendaLayout->setSpacing(SPACING);
 
     // Create agenda
@@ -1700,7 +1700,7 @@ void AgendaView::createTimeBarHeaders()
         d->mTimeBarHeaderFrame->layout()->addWidget(label);
         label->setFont(labelFont);
         label->setAlignment(Qt::AlignBottom | Qt::AlignRight);
-        label->setContentsMargins(0, 0, 0, 0);
+        label->setContentsMargins({});
         label->setWordWrap(true);
         label->setToolTip(timeLabel->headerToolTip());
         d->mTimeBarHeaders.append(label);
@@ -1753,8 +1753,9 @@ static QDateTime copyTimeSpec(QDateTime dt, const QDateTime &source)
     case Qt::TimeZone:
         return dt.toTimeZone(source.timeZone());
     case Qt::LocalTime:
+        return dt.toTimeZone(QTimeZone::LocalTime);
     case Qt::UTC:
-        return dt.toTimeSpec(source.timeSpec());
+        return dt.toTimeZone(QTimeZone::UTC);
     case Qt::OffsetFromUTC:
         return dt.toOffsetFromUtc(source.offsetFromUtc());
     }
@@ -2078,8 +2079,8 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
     KCalendarCore::Event::Ptr event = CalendarSupport::event(incidence);
     const QDate today = QDate::currentDate();
 
-    QDateTime firstVisibleDateTime(d->mSelectedDates.first(), QTime(0, 0, 0), Qt::LocalTime);
-    QDateTime lastVisibleDateTime(d->mSelectedDates.last(), QTime(23, 59, 59, 999), Qt::LocalTime);
+    QDateTime firstVisibleDateTime(d->mSelectedDates.first(), QTime(0, 0, 0), QTimeZone::LocalTime);
+    QDateTime lastVisibleDateTime(d->mSelectedDates.last(), QTime(23, 59, 59, 999), QTimeZone::LocalTime);
 
     // Optimization, very cheap operation that discards incidences that aren't in the timespan
     if (!d->mightBeVisible(incidence)) {
@@ -2156,7 +2157,7 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
     }
 
     // ToDo items shall be displayed today if they are overdue
-    const QDateTime dateTimeToday = QDateTime(today, QTime(0, 0), Qt::LocalTime);
+    const QDateTime dateTimeToday = QDateTime(today, QTime(0, 0), QTimeZone::LocalTime);
     if (todo && todo->isOverdue() && dateTimeToday >= firstVisibleDateTime && dateTimeToday <= lastVisibleDateTime) {
         /* If there's a recurring instance showing up today don't add "today" again
          * we don't want the event to appear duplicated */
@@ -2287,7 +2288,7 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
 
     const QDate day = d->mSelectedDates[gpos.x()];
     const QTime time = d->mAgenda->gyToTime(gpos.y());
-    QDateTime newTime(day, time, Qt::LocalTime);
+    QDateTime newTime(day, time, QTimeZone::LocalTime);
 
     for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         const Akonadi::Item existingItem = d->mViewCalendar->item(incidence);
@@ -2417,7 +2418,7 @@ void AgendaView::newTimeSpanSelectedAllDay(const QPoint &start, const QPoint &en
 
 void AgendaView::newTimeSpanSelected(const QPoint &start, const QPoint &end)
 {
-    if (!d->mSelectedDates.count()) {
+    if (d->mSelectedDates.isEmpty()) {
         return;
     }
 
@@ -2521,6 +2522,7 @@ QSplitter *AgendaView::splitter() const
 
 bool AgendaView::filterByCollectionSelection(const KCalendarCore::Incidence::Ptr &incidence)
 {
+    Q_UNUSED(incidence);
     return true;
     /*
     const Akonadi::Item item = d->mViewCalendar->item(incidence);
